package
Version:
v0.0.0-...-b1029ed
Opens a new window with list of versions in this module.
Published: Dec 14, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Server Server `mapstructure:"SERVER"`
Redis Redis `mapstructure:"REDIS"`
WALogger WALogger `mapstructure:"WALOGGER"`
}
type Redis struct {
Host string `mapstructure:"HOST"`
Port string `mapstructure:"PORT"`
Password string `mapstructure:"PASSWORD"`
}
type Server struct {
Address string `mapstructure:"ADDRESS"`
}
type WALogger struct {
Scheme string `mapstructure:"SCHEME"`
Host string `mapstructure:"HOST"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.